==> advanced-power-monitor-src_0.5.1-2.tar.gz: advanced-power-monitor-src-0.5.1/src/usr/src/advanced-power-monitor/Util.py <==

'''
Advanced Power Monitor Utility Library
2008-2009(c) Kirill Plyashkevich <ru.spirit@gmail.com>
Connects to bunch of dbus signals, monitors values change and emmits signal in case of update.
'''

import os, os.path, sys
import gobject, threading
gobject.threads_init()
try:
  import subprocess
except ImportError:
  import commands


def print_exception_message(place, e):
  print "%s: %s" % (place, str(e))

class File:

  @staticmethod
  def get_lines(filename):
    lines = []
    fd = None
    try:
      fd = open(filename, 'r')
    except Exception, e:
      print_exception_message('%s.File.get_lines(\'%s\')' % (__name__, filename), e)
    else:
      try:
        lines = fd.readlines()
        lines = [l.replace('\n', '') for l in lines if l]
      except Exception, e:
        print_exception_message('%s.File.get_lines(\'%s\')' % (__name__, filename), e)
      finally:
        fd.close()
    return lines

class Module():
  file_extensions = ('.py', '.pyc', '.pyo')
  ignored_filenames = ('__init__.py', '__init__.pyc', '__init__.pyo')
  ignored_startswith = ('Abstract')

  @staticmethod
  def import_module(name):
    try:
      return sys.modules[name]
    except KeyError:
      pass
    except Exception, e:
      print_exception_message('%s.Module.import_module(\'%s\')' % (__name__, name), e)
    mod = None
    try:
      mod = __import__(name)
      components = name.split('.')[1:]
      for comp in components:
        mod = getattr(mod, comp)
    except ImportError, e:
      print_exception_message('%s.Module.import_module(\'%s\')' % (__name__, name), e)
    return mod

  @staticmethod
  def import_modules(modules):
    modules_list = set()
    try:
      c_iter = iter(modules)
      while c_iter:
        modules_list.add(Module.import_module(c_iter.next()))
    except StopIteration:
      pass
    except Exception, e:
      print_exception_message('%s.Module.import_modules(%s)' % (__name__, modules), e)
    return modules_list

  @staticmethod
  def get_module_class(module):
    if module:
      classname = module.__name__.split('.')[-1]
      return Module.get_class_object(module, classname)
    else:
      return None

  @staticmethod
  def has_module_class(module):
    class_object = None
    try:
      class_object = module.__dict__[classname]
    except KeyError, e:
      print_exception_message('%s.Module.has_class_object(\'%s\', \'%s\')' % (__name__, module, classname), e)
    return class_object != None

  @staticmethod
  def get_class_object(module, classname):
    class_object = None
    try:
      class_object = module.__dict__[classname]
    except KeyError, e:
      print_exception_message('%s.Module.get_class_object(\'%s\', \'%s\')' % (__name__, module, classname), e)
    return class_object

  @staticmethod
  def get_modules_list(root, path):
    cdir = os.path.join(root, path)
    cdirs = os.listdir(cdir)
    dirs = [f for f in cdirs if os.path.isdir(os.path.join(cdir, f))]
    modules_list = dict()

    def check_path(arg, dirname, files):
      cmodule = dirname.replace(root, '').replace(os.sep, '.')
      if cmodule.startswith('.'):
        cmodule = cmodule[1:]
      modules_list[cmodule] = set()
      files = [f for f in files if os.path.isfile(os.path.join(dirname, f)) and not f in Module.ignored_filenames and not f.startswith(Module.ignored_startswith) and f.endswith(Module.file_extensions)]
      for f in files:
        submodule = f.rsplit('.')[0]
        modules_list[cmodule].add('%s.%s' % (cmodule, submodule))

    os.path.walk(cdir, check_path, '')
    return modules_list

class Shell:

  @staticmethod
  def run_async(func, args=[], kwargs={}):
    newThread = threading.Thread(target=func, args=args, kwargs=kwargs)
    newThread.start()

  @staticmethod
  def run_command_async(cmd):
    Shell.run_async(Shell.run_command, [cmd])

  @staticmethod
  def run_command(cmd):
    try:
      subprocess.call(cmd, shell=True)
    except NameError:
      os.system(cmd)

  @staticmethod
  def get_command_output(cmd):
    result = ''
    try:
      result = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE).communicate()[0]
    except NameError:
      result = commands.getoutput(cmd)
    return result

class System:

  installed_packages = set()

  devices = {'SU-18': 'Nokia 770',
             'RX-34': 'Nokia N800',
             'RX-44': 'Nokia N810',
             'RX-48': 'Nokia N810WE',
             'RX-51': 'Nokia N900'
            }

  @staticmethod
  def get_device_name(device_code):
    try:
      return System.devices[device_code]
    except KeyError:
      return 'Unknown'

  @staticmethod
  def get_installed_packages(refresh=False):
    if refresh or not System.installed_packages:
      print 'Loading packages list...'
      lines = File.get_lines('/var/lib/dpkg/status')
      packages = set()
      pkey = ''
      for x in lines:
        if x.startswith('Package'):
          pkey = x.replace('Package: ', '')
        elif x.startswith('Status') and x.rfind('ok installed') != -1:
          packages.add(pkey)
      System.installed_packages = packages
    return System.installed_packages

  @staticmethod
  def is_package_installed(package_name):
    tmp = set()
    tmp.add(package_name)
    return System.are_packages_installed(tmp)

  @staticmethod
  def are_packages_installed(packages):
    if not System.installed_packages:
      System.get_installed_packages()
    return set(packages).issubset(System.installed_packages)

  @staticmethod
  def process_meminfo(lines, filter_src):
    mem_sum = 0
    filter_array = []
    filter_array.extend(filter_src)
    for x in lines:
      c_filter_array = [f for f in filter_array if x.startswith(f)]
      if c_filter_array:
        mem_sum += long(x[0:x.rfind(' ')].replace('%s:' % c_filter_array[0], ''))
        filter_array.remove(c_filter_array[0])
    return mem_sum

==> advanced-power-monitor-src_0.5.1-5.tar.gz: advanced-power-monitor-src-0.5.1/src/usr/src/advanced-power-monitor/Util.py <==

'''
Advanced Power Monitor Utility Library
2008-2010(c) Kirill Plyashkevich <ru.spirit@gmail.com>
Connects to bunch of dbus signals, monitors values change and emmits signal in case of update.
'''

import os, os.path, sys
import gobject, threading
gobject.threads_init()
try:
  import subprocess
except ImportError:
  import commands


def print_exception_message(place, e):
  print "%s: %s" % (place, str(e))

class File:

  @staticmethod
  def get_lines(filename):
    lines = []
    fd = None
    message_title = '%s.File.get_lines(\'%s\')' % (__name__, filename)
    try:
      fd = open(filename, 'r')
    except Exception, e:
      print_exception_message(message_title, e)
    else:
      try:
        lines = fd.readlines()
        lines = [l.replace('\n', '') for l in lines if l]
      except Exception, e:
        print_exception_message(message_title, e)
      finally:
        fd.close()
    return lines

class Module():
  file_extensions = ('.py', '.pyc', '.pyo')
  ignored_filenames = ('__init__.py', '__init__.pyc', '__init__.pyo')
  ignored_startswith = ('Abstract')

  @staticmethod
  def import_module(name):
    try:
      return sys.modules[name]
    except KeyError:
      pass
    except Exception, e:
      print_exception_message('%s.Module.import_module(\'%s\')' % (__name__, name), e)
    mod = None
    try:
      mod = __import__(name)
      components = name.split('.')[1:]
      for comp in components:
        mod = getattr(mod, comp)
    except ImportError, e:
      print_exception_message('%s.Module.import_module(\'%s\')' % (__name__, name), e)
    return mod

  @staticmethod
  def import_modules(modules):
    modules_list = set()
    try:
      c_iter = iter(modules)
      while c_iter:
        modules_list.add(Module.import_module(c_iter.next()))
    except StopIteration:
      pass
    except Exception, e:
      print_exception_message('%s.Module.import_modules(%s)' % (__name__, modules), e)
    return modules_list

  @staticmethod
  def get_module_class(module):
    if module:
      classname = module.__name__.split('.')[-1]
      return Module.get_class_object(module, classname)
    else:
      return None

  @staticmethod
  def has_module_class(module):
    class_object = None
    try:
      class_object = module.__dict__[classname]
    except KeyError, e:
      print_exception_message('%s.Module.has_class_object(\'%s\', \'%s\')' % (__name__, module, classname), e)
    return class_object != None

  @staticmethod
  def get_class_object(module, classname):
    class_object = None
    try:
      class_object = module.__dict__[classname]
    except KeyError, e:
      print_exception_message('%s.Module.get_class_object(\'%s\', \'%s\')' % (__name__, module, classname), e)
    return class_object

  @staticmethod
  def get_modules_list(root, path):
    cdir = os.path.join(root, path)
    cdirs = os.listdir(cdir)
    dirs = [f for f in cdirs if os.path.isdir(os.path.join(cdir, f))]
    modules_list = dict()

    def check_path(arg, dirname, files):
      cmodule = dirname.replace(root, '').replace(os.sep, '.')
      if cmodule.startswith('.'):
        cmodule = cmodule[1:]
      modules_list[cmodule] = set()
      files = [f for f in files if os.path.isfile(os.path.join(dirname, f)) and not f in Module.ignored_filenames and not f.startswith(Module.ignored_startswith) and f.endswith(Module.file_extensions)]
      for f in files:
        submodule = f.rsplit('.')[0]
        modules_list[cmodule].add('%s.%s' % (cmodule, submodule))

    os.path.walk(cdir, check_path, '')
    return modules_list

class Shell:

  @staticmethod
  def run_async(func, args=[], kwargs={}):
    newThread = threading.Thread(target=func, args=args, kwargs=kwargs)
    newThread.start()

  @staticmethod
  def run_command_async(cmd):
    Shell.run_async(Shell.run_command, [cmd])

  @staticmethod
  def run_command(cmd):
    try:
      subprocess.call(cmd, shell=True)
    except NameError:
      os.system(cmd)

  @staticmethod
  def get_command_output(cmd):
    result = ''
    try:
      result = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE).communicate()[0]
    except NameError:
      result = commands.getoutput(cmd)
    return result

class System:

  installed_packages = {}

  devices = {'SU-18': 'Nokia 770',
             'RX-34': 'Nokia N800',
             'RX-44': 'Nokia N810',
             'RX-48': 'Nokia N810WE',
             'RX-51': 'Nokia N900'
            }

  @staticmethod
  def get_device_name(device_code):
    try:
      return System.devices[device_code]
    except KeyError:
      return 'Unknown'

  @staticmethod
  def get_installed_packages(refresh=False):
    if refresh or not System.installed_packages:
      print 'Loading packages list...'
      lines = File.get_lines('/var/lib/dpkg/status')
      packages = {}
      pkey = ''
      installed_ok = False
      for x in lines:
        if x.startswith('Package: '):
          pkey = x.replace('Package: ', '')
          installed_ok = False
        elif x.startswith('Status: ') and x.rfind('ok installed') != -1:
          installed_ok = True
        elif x.startswith('Version: ') and installed_ok:
          packages[pkey] = x.replace('Version: ', '')
          installed_ok = False
        else:
          continue
      System.installed_packages = packages
    return System.installed_packages

  @staticmethod
  def is_package_installed(package_name):
    if not System.installed_packages:
      System.get_installed_packages()
    return System.installed_packages.has_key(package_name)

  @staticmethod
  def are_packages_installed(packages):
    if not System.installed_packages:
      System.get_installed_packages()
    return set(packages).issubset(set(System.installed_packages.keys()))

  @staticmethod
  def is_package_version_valid(package, version):
    if not System.installed_packages:
      System.get_installed_packages()
    try:
      return System.installed_packages[package] >= version
    except:
      return False

  @staticmethod
  def process_meminfo(lines, filter_src):
    mem_sum = 0
    filter_array = []
    filter_array.extend(filter_src)
    for x in lines:
      c_filter_array = [f for f in filter_array if x.startswith(f)]
      if c_filter_array:
        mem_sum += long(x[0:x.rfind(' ')].replace('%s:' % c_filter_array[0], ''))
        filter_array.remove(c_filter_array[0])
    return mem_sum
